@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ ImportFilterInfoGui::ImportFilterInfoGui(ImportMailPage *parent)
 {
 }
 
-ImportFilterInfoGui::~ImportFilterInfoGui()
-{
-}
+ImportFilterInfoGui::~ImportFilterInfoGui() = default;
 
 void ImportFilterInfoGui::setStatusMessage(const QString &status)
 {
