@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,13 +10,9 @@
 #include <KSharedConfig>
 using namespace LibImportWizard;
 
-AbstractCalendar::AbstractCalendar()
-{
-}
+AbstractCalendar::AbstractCalendar() = default;
 
-AbstractCalendar::~AbstractCalendar()
-{
-}
+AbstractCalendar::~AbstractCalendar() = default;
 
 void AbstractCalendar::addImportInfo(const QString &log)
 {
