@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,9 +8,7 @@
 
 using namespace LibImportWizard;
 
-AbstractDisplayInfo::AbstractDisplayInfo()
-{
-}
+AbstractDisplayInfo::AbstractDisplayInfo() = default;
 
 void AbstractDisplayInfo::calendarImportError(const QString &log)
 {
