@@ -8,26 +8,26 @@
 #include "manualselectfilterpage.h"
 
 // Filter includes
-#include <filterevolution.h>
-#include <filterevolution_v2.h>
-#include <filtericedove.h>
-#include <filterkmail_maildir.h>
-#include <filterkmailarchive.h>
-#include <filterlnotes.h>
-#include <filtermailapp.h>
-#include <filtermailmangzip.h>
-#include <filtermbox.h>
-#include <filteroe.h>
-#include <filteropera.h>
-#include <filterplain.h>
-#include <filterpmail.h>
-#include <filtersylpheed.h>
-#include <filterthebat.h>
-#include <filterthunderbird.h>
+#include <MailImporter/FilterEvolution>
+#include <MailImporter/FilterEvolution_v2>
+#include <MailImporter/FilterIcedove>
+#include <MailImporter/FilterKMailArchive>
+#include <MailImporter/FilterKMail_maildir>
+#include <MailImporter/FilterLNotes>
+#include <MailImporter/FilterMBox>
+#include <MailImporter/FilterMailApp>
+#include <MailImporter/FilterMailmanGzip>
+#include <MailImporter/FilterOE>
+#include <MailImporter/FilterOpera>
+#include <MailImporter/FilterPMail>
+#include <MailImporter/FilterPlain>
+#include <MailImporter/FilterSylpheed>
+#include <MailImporter/FilterTheBat>
+#include <MailImporter/FilterThunderbird>
 
-#include <filters.h>
+#include <MailImporter/Filters>
 
-#include <filterevolution_v3.h>
+#include <MailImporter/FilterEvolution_v3>
 
 // KDE includes
 
