@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ BalsaSettings::BalsaSettings(const QString &filename)
 {
 }
 
-BalsaSettings::~BalsaSettings()
-{
-}
+BalsaSettings::~BalsaSettings() = default;
 
 void BalsaSettings::importSettings()
 {
