@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ IcedoveImportData::IcedoveImportData(QObject *parent, const QList<QVariant> &)
     mPath = MailImporter::FilterIcedove::defaultSettingsPath();
 }
 
-IcedoveImportData::~IcedoveImportData()
-{
-}
+IcedoveImportData::~IcedoveImportData() = default;
 
 QString IcedoveImportData::defaultProfile()
 {
